@@ -32,7 +32,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QToolButton>
 #include <QWidgetAction>
 #include <QTimer>
-#include <QDebug>
+#include "gwenview_app_debug.h"
 
 // KDE
 #include <KActionCollection>
@@ -72,11 +72,11 @@ public:
         mLayout->setContentsMargins(0, 0, 0, 0);
     }
 
-    void addAction(QAction* action)
+    void addAction(QAction* action, Qt::ToolButtonStyle style = Qt::ToolButtonIconOnly)
     {
         QToolButton* button = new QToolButton;
         button->setDefaultAction(action);
-        button->setToolButtonStyle(Qt::ToolButtonIconOnly);
+        button->setToolButtonStyle(style);
         button->setAutoRaise(true);
         const int extent = KIconLoader::SizeMedium;
         button->setIconSize(QSize(extent, extent));
@@ -139,6 +139,8 @@ void FullScreenContent::init(KActionCollection* actionCollection, QWidget* autoH
     mToolBar = new FullScreenToolBar(mContent);
 
     #define addAction(name) mToolBar->addAction(actionCollection->action(name))
+    addAction("toggle_sidebar");
+    mToolBar->addSeparator();
     addAction("browse");
     addAction("view");
     mToolBar->addSeparator();
@@ -194,8 +196,8 @@ void FullScreenContent::init(KActionCollection* actionCollection, QWidget* autoH
 
     // Right bar
     mRightToolBar = new FullScreenToolBar(mContent);
-    mRightToolBar->addAction(mActionCollection->action("leave_fullscreen"));
-    mRightToolBar->addAction(mOptionsAction);
+    mRightToolBar->addAction(mActionCollection->action("leave_fullscreen"), Qt::ToolButtonFollowStyle);
+    mRightToolBar->addAction(mOptionsAction, Qt::ToolButtonFollowStyle);
     mRightToolBar->addStretch();
     mRightToolBar->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
     mRightToolBarShadow = new ShadowFilter(mRightToolBar);
@@ -405,8 +407,8 @@ void FullScreenContent::createOptionsAction()
     // if the mode is changed to thumbnail-mode, we want the option button
     // to remain visible
     mOptionsAction = new QAction(this);
-    mOptionsAction->setPriority(QAction::LowPriority);
     mOptionsAction->setIcon(QIcon::fromTheme("configure"));
+    mOptionsAction->setText(i18n("Configure"));
     mOptionsAction->setToolTip(i18nc("@info:tooltip", "Configure full screen mode"));
     QObject::connect(mOptionsAction, &QAction::triggered, this, &FullScreenContent::showOptionsMenu);
 }
@@ -482,14 +484,14 @@ void FullScreenContent::showOptionsMenu()
     QPoint pos;
     QWidget* button = mOptionsAction->associatedWidgets().constFirst();
     Q_ASSERT(button);
-    qWarning() << button << button->geometry();
+    qCWarning(GWENVIEW_APP_LOG) << button << button->geometry();
     if (QApplication::isRightToLeft()) {
         pos = button->mapToGlobal(button->rect().bottomLeft());
     } else {
         pos = button->mapToGlobal(button->rect().bottomRight());
         pos.rx() -= menu.sizeHint().width();
     }
-    qWarning() << pos;
+    qCWarning(GWENVIEW_APP_LOG) << pos;
     menu.exec(pos);
 }
 
