@@ -31,7 +31,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #include <QPushButton>
 #include <QSpinBox>
 #include <QtMath>
-#include <QDebug>
+#include "gwenview_lib_debug.h"
 #include <QLineEdit>
 
 // KDE
@@ -49,7 +49,7 @@ namespace Gwenview
 
 // Euclidean algorithm to compute the greatest common divisor of two integers.
 // Found at:
-// http://en.wikipedia.org/wiki/Euclidean_algorithm
+// https://en.wikipedia.org/wiki/Euclidean_algorithm
 static int gcd(int a, int b)
 {
     return b == 0 ? a : gcd(b, a % b);
@@ -409,7 +409,11 @@ CropWidget::CropWidget(QWidget* parent, RasterImageView* imageView, CropTool* cr
     // Index Changed: required so that choosing an item with the same text is detected (e.g. going from US Letter portrait
     // to US Letter landscape)
     connect(d->ratioComboBox, &QComboBox::editTextChanged, this, &CropWidget::slotRatioComboBoxChanged);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(d->ratioComboBox, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &CropWidget::slotRatioComboBoxChanged);
+#else
+    connect(d->ratioComboBox, QOverload<int, const QString &>::of(&QComboBox::currentIndexChanged), this, &CropWidget::slotRatioComboBoxChanged);
+#endif
 
     // Don't do this before signals are connected, otherwise the tool won't get
     // initialized
