@@ -31,7 +31,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QGraphicsProxyWidget>
 #include <QMouseEvent>
 #include <QElapsedTimer>
-#include <QDebug>
+#include "gwenview_lib_debug.h"
 #include <QIcon>
 #include <QTime>
 
