@@ -23,7 +23,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include "recentfilesmodel.h"
 
 // Qt
-#include <QDebug>
+#include "gwenview_lib_debug.h"
 #include <QUrl>
 #include <QMimeDatabase>
 #include <QRegularExpression>
